import React, { useState } from 'react';
import { Button, Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from '../components';
import { Fullscreen, Schema as SchemaIcon, Search as SearchIcon } from '@mui/icons-material';
import ColorMode from '../components/color-mode';

export type SideNavTab = 'Schema' | 'Search' | undefined;
const tabs: Array<{
  name: SideNavTab;
  icon: JSX.Element;
}> = [
  {
    name: 'Search',
    icon: <SearchIcon />,
  },
  { name: 'Schema', icon: <SchemaIcon /> },
];

export function Sidebar({ onTab, tab }: { onTab: (tab: SideNavTab) => void; tab: SideNavTab }) {
  return (
    <div className="side-bar w-fit h-full flex shrink">
      <TooltipProvider delayDuration={100}>
        <div className="w-11 flex flex-col items-center">
          {tabs.map((t) => (
            <Tooltip key={t.name}>
              <TooltipTrigger asChild>
                <Button
                  variantType="secondary"
                  variant="ghost"
                  size="sm"
                  iconComponent={t.icon}
                  onClick={() => {
                    if (tab === t.name) {
                      onTab(undefined);
                    } else {
                      onTab(t.name);
                    }
                  }}
                  className={tab === t.name ? 'bg-secondary-100' : ''}
                />
              </TooltipTrigger>
              <TooltipContent side={'right'}>{t.name}</TooltipContent>
            </Tooltip>
          ))}
          <div className="mt-auto mb-2">
            <ColorMode />
          </div>
        </div>
      </TooltipProvider>
    </div>
  );
}
